pygerber.parser.blender.apertures.util module
=============================================

.. automodule:: pygerber.parser.blender.apertures.util
   :members:
   :undoc-members:
   :show-inheritance:
